@@ -22,14 +22,8 @@ class DashboardsService(
     PaginationMixin,
 ):
     def __init__(self, base: BaseService) -> None:
-
-        # init mixins
-        FavoriteMixin.__init__(self, base)
-        CommonMixin.__init__(self, base)
-        PublishMixin.__init__(self, base)
+        super().__init__(base=base)
         PaginationMixin.__init__(self, base)
-
-        self.__base = base
         self.endpoint = "/api/dashboards"
 
     def get_all(self) -> List[Dict]:
