@@ -4,11 +4,7 @@ from .mixins import CommonMixin, NameMixin, PrintMixin
 
 class UsersService(CommonMixin, NameMixin, PrintMixin):
     def __init__(self, base: BaseService) -> None:
-
-        # init mixins
-        CommonMixin.__init__(self, base)
-
-        self.__base = base
+        super().__init__(base=base)
         self.endpoint = "/api/users"
 
     def disable(self, user_id: int) -> None:
